# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from finnhub.configuration import Configuration


class Investor(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'share': 'int',
        'turnover': 'str',
        'turnover_percent': 'float',
        'change': 'int',
        'filing_date': 'date'
    }

    attribute_map = {
        'name': 'name',
        'share': 'share',
        'turnover': 'turnover',
        'turnover_percent': 'turnoverPercent',
        'change': 'change',
        'filing_date': 'filingDate'
    }

    def __init__(self, name=None, share=None, turnover=None, turnover_percent=None, change=None, filing_date=None, local_vars_configuration=None):  # noqa: E501
        """Investor - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._share = None
        self._turnover = None
        self._turnover_percent = None
        self._change = None
        self._filing_date = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if share is not None:
            self.share = share
        if turnover is not None:
            self.turnover = turnover
        if turnover_percent is not None:
            self.turnover_percent = turnover_percent
        if change is not None:
            self.change = change
        if filing_date is not None:
            self.filing_date = filing_date

    @property
    def name(self):
        """Gets the name of this Investor.  # noqa: E501

        Investor's name.  # noqa: E501

        :return: The name of this Investor.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Investor.

        Investor's name.  # noqa: E501

        :param name: The name of this Investor.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def share(self):
        """Gets the share of this Investor.  # noqa: E501

        Number of shares held by the investor.  # noqa: E501

        :return: The share of this Investor.  # noqa: E501
        :rtype: int
        """
        return self._share

    @share.setter
    def share(self, share):
        """Sets the share of this Investor.

        Number of shares held by the investor.  # noqa: E501

        :param share: The share of this Investor.  # noqa: E501
        :type: int
        """

        self._share = share

    @property
    def turnover(self):
        """Gets the turnover of this Investor.  # noqa: E501

        Turnover rating of the investor.  # noqa: E501

        :return: The turnover of this Investor.  # noqa: E501
        :rtype: str
        """
        return self._turnover

    @turnover.setter
    def turnover(self, turnover):
        """Sets the turnover of this Investor.

        Turnover rating of the investor.  # noqa: E501

        :param turnover: The turnover of this Investor.  # noqa: E501
        :type: str
        """

        self._turnover = turnover

    @property
    def turnover_percent(self):
        """Gets the turnover_percent of this Investor.  # noqa: E501

        Trading's values relative to investor's assets expressed in percentage.  # noqa: E501

        :return: The turnover_percent of this Investor.  # noqa: E501
        :rtype: float
        """
        return self._turnover_percent

    @turnover_percent.setter
    def turnover_percent(self, turnover_percent):
        """Sets the turnover_percent of this Investor.

        Trading's values relative to investor's assets expressed in percentage.  # noqa: E501

        :param turnover_percent: The turnover_percent of this Investor.  # noqa: E501
        :type: float
        """

        self._turnover_percent = turnover_percent

    @property
    def change(self):
        """Gets the change of this Investor.  # noqa: E501

        Number of share changed (net buy or sell) from the last period.  # noqa: E501

        :return: The change of this Investor.  # noqa: E501
        :rtype: int
        """
        return self._change

    @change.setter
    def change(self, change):
        """Sets the change of this Investor.

        Number of share changed (net buy or sell) from the last period.  # noqa: E501

        :param change: The change of this Investor.  # noqa: E501
        :type: int
        """

        self._change = change

    @property
    def filing_date(self):
        """Gets the filing_date of this Investor.  # noqa: E501

        Filing date.  # noqa: E501

        :return: The filing_date of this Investor.  # noqa: E501
        :rtype: date
        """
        return self._filing_date

    @filing_date.setter
    def filing_date(self, filing_date):
        """Sets the filing_date of this Investor.

        Filing date.  # noqa: E501

        :param filing_date: The filing_date of this Investor.  # noqa: E501
        :type: date
        """

        self._filing_date = filing_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Investor):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Investor):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from finnhub.configuration import Configuration


class UpgradeDowngrade(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'symbol': 'str',
        'grade_time': 'int',
        'from_grade': 'str',
        'to_grade': 'str',
        'company': 'str',
        'action': 'str'
    }

    attribute_map = {
        'symbol': 'symbol',
        'grade_time': 'gradeTime',
        'from_grade': 'fromGrade',
        'to_grade': 'toGrade',
        'company': 'Company',
        'action': 'action'
    }

    def __init__(self, symbol=None, grade_time=None, from_grade=None, to_grade=None, company=None, action=None, local_vars_configuration=None):  # noqa: E501
        """UpgradeDowngrade - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._symbol = None
        self._grade_time = None
        self._from_grade = None
        self._to_grade = None
        self._company = None
        self._action = None
        self.discriminator = None

        if symbol is not None:
            self.symbol = symbol
        if grade_time is not None:
            self.grade_time = grade_time
        if from_grade is not None:
            self.from_grade = from_grade
        if to_grade is not None:
            self.to_grade = to_grade
        if company is not None:
            self.company = company
        if action is not None:
            self.action = action

    @property
    def symbol(self):
        """Gets the symbol of this UpgradeDowngrade.  # noqa: E501

        Company symbol.  # noqa: E501

        :return: The symbol of this UpgradeDowngrade.  # noqa: E501
        :rtype: str
        """
        return self._symbol

    @symbol.setter
    def symbol(self, symbol):
        """Sets the symbol of this UpgradeDowngrade.

        Company symbol.  # noqa: E501

        :param symbol: The symbol of this UpgradeDowngrade.  # noqa: E501
        :type: str
        """

        self._symbol = symbol

    @property
    def grade_time(self):
        """Gets the grade_time of this UpgradeDowngrade.  # noqa: E501

        Upgrade/downgrade time in UNIX timestamp.  # noqa: E501

        :return: The grade_time of this UpgradeDowngrade.  # noqa: E501
        :rtype: int
        """
        return self._grade_time

    @grade_time.setter
    def grade_time(self, grade_time):
        """Sets the grade_time of this UpgradeDowngrade.

        Upgrade/downgrade time in UNIX timestamp.  # noqa: E501

        :param grade_time: The grade_time of this UpgradeDowngrade.  # noqa: E501
        :type: int
        """

        self._grade_time = grade_time

    @property
    def from_grade(self):
        """Gets the from_grade of this UpgradeDowngrade.  # noqa: E501

        From grade.  # noqa: E501

        :return: The from_grade of this UpgradeDowngrade.  # noqa: E501
        :rtype: str
        """
        return self._from_grade

    @from_grade.setter
    def from_grade(self, from_grade):
        """Sets the from_grade of this UpgradeDowngrade.

        From grade.  # noqa: E501

        :param from_grade: The from_grade of this UpgradeDowngrade.  # noqa: E501
        :type: str
        """

        self._from_grade = from_grade

    @property
    def to_grade(self):
        """Gets the to_grade of this UpgradeDowngrade.  # noqa: E501

        To grade.  # noqa: E501

        :return: The to_grade of this UpgradeDowngrade.  # noqa: E501
        :rtype: str
        """
        return self._to_grade

    @to_grade.setter
    def to_grade(self, to_grade):
        """Sets the to_grade of this UpgradeDowngrade.

        To grade.  # noqa: E501

        :param to_grade: The to_grade of this UpgradeDowngrade.  # noqa: E501
        :type: str
        """

        self._to_grade = to_grade

    @property
    def company(self):
        """Gets the company of this UpgradeDowngrade.  # noqa: E501

        Company/analyst who did the upgrade/downgrade.  # noqa: E501

        :return: The company of this UpgradeDowngrade.  # noqa: E501
        :rtype: str
        """
        return self._company

    @company.setter
    def company(self, company):
        """Sets the company of this UpgradeDowngrade.

        Company/analyst who did the upgrade/downgrade.  # noqa: E501

        :param company: The company of this UpgradeDowngrade.  # noqa: E501
        :type: str
        """

        self._company = company

    @property
    def action(self):
        """Gets the action of this UpgradeDowngrade.  # noqa: E501

        Action can take any of the following values: <code>up(upgrade), down(downgrade), main(maintains), init(initiate), reit(reiterate)</code>.  # noqa: E501

        :return: The action of this UpgradeDowngrade.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this UpgradeDowngrade.

        Action can take any of the following values: <code>up(upgrade), down(downgrade), main(maintains), init(initiate), reit(reiterate)</code>.  # noqa: E501

        :param action: The action of this UpgradeDowngrade.  # noqa: E501
        :type: str
        """

        self._action = action

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpgradeDowngrade):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpgradeDowngrade):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "0.0.1"

# import apis into sdk package
from finnhub.api.default_api import DefaultApi

# import ApiClient
from finnhub.api_client import ApiClient
from finnhub.configuration import Configuration
from finnhub.exceptions import OpenApiException
from finnhub.exceptions import ApiTypeError
from finnhub.exceptions import ApiValueError
from finnhub.exceptions import ApiKeyError
from finnhub.exceptions import ApiException
# import models into sdk package
from finnhub.models.aggregate_indicators import AggregateIndicators
from finnhub.models.covid19 import COVID19
from finnhub.models.company import Company
from finnhub.models.company_executive import CompanyExecutive
from finnhub.models.company_news_statistics import CompanyNewsStatistics
from finnhub.models.company_profile import CompanyProfile
from finnhub.models.company_profile2 import CompanyProfile2
from finnhub.models.crypto_candles import CryptoCandles
from finnhub.models.crypto_symbol import CryptoSymbol
from finnhub.models.development import Development
from finnhub.models.dividends import Dividends
from finnhub.models.earning_estimate import EarningEstimate
from finnhub.models.earning_release import EarningRelease
from finnhub.models.earning_result import EarningResult
from finnhub.models.earnings_call_transcripts import EarningsCallTranscripts
from finnhub.models.earnings_call_transcripts_list import EarningsCallTranscriptsList
from finnhub.models.earnings_estimates import EarningsEstimates
from finnhub.models.estimate import Estimate
from finnhub.models.filing import Filing
from finnhub.models.financial_statements import FinancialStatements
from finnhub.models.financials_as_reported import FinancialsAsReported
from finnhub.models.forex_candles import ForexCandles
from finnhub.models.forex_symbol import ForexSymbol
from finnhub.models.forexrates import Forexrates
from finnhub.models.fund_ownership import FundOwnership
from finnhub.models.ipo_event import IPOEvent
from finnhub.models.indicator import Indicator
from finnhub.models.investor import Investor
from finnhub.models.investors_ownership import InvestorsOwnership
from finnhub.models.major_developments import MajorDevelopments
from finnhub.models.metrics import Metrics
from finnhub.models.news import News
from finnhub.models.news_sentiment import NewsSentiment
from finnhub.models.price_target import PriceTarget
from finnhub.models.quote import Quote
from finnhub.models.recommendation_trends import RecommendationTrends
from finnhub.models.report import Report
from finnhub.models.revenue_estimates import RevenueEstimates
from finnhub.models.sentiment import Sentiment
from finnhub.models.splits import Splits
from finnhub.models.stock import Stock
from finnhub.models.stock_candles import StockCandles
from finnhub.models.stock_transcripts import StockTranscripts
from finnhub.models.technical_analysis import TechnicalAnalysis
from finnhub.models.technical_indicators import TechnicalIndicators
from finnhub.models.tick_data import TickData
from finnhub.models.transcript_content import TranscriptContent
from finnhub.models.transcript_participant import TranscriptParticipant
from finnhub.models.trend import Trend
from finnhub.models.upgrade_downgrade import UpgradeDowngrade

